#!/bin/csh -f

# shell program to use preprocess.pl on the train.xml and test.xml
# files.

# subtest 1
echo "Running preprocess.pl on train.xml using token.txt"

set TESTFILE     = "train.xml"
set TOKENFILE    = "token.txt"

set TARGETFILE_1 = "art.train.xml.reqd"   
set TARGETFILE_2 = "art.train.count.reqd"   
set TARGETFILE_3 = "authority.train.xml.reqd"   
set TARGETFILE_4 = "authority.train.count.reqd"   

# first check if these files exist. if any one does not, quit
if (!(-e $TESTFILE)) then
    echo "File $TESTFILE does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_1)) then
    echo "File $TARGETFILE_1 does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_2)) then
    echo "File $TARGETFILE_2 does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_3)) then
    echo "File $TARGETFILE_3 does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_4)) then
    echo "File $TARGETFILE_4 does not exist... aborting"
    exit
endif

# test on train.xml...
echo "Testing preprocess thusly: preprocess.pl $TESTFILE"
preprocess.pl $TESTFILE --token $TOKENFILE

# find diffs
diff art.n.xml $TARGETFILE_1 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_1)"
else
    echo "Following differences exist between art.n.xml and $TARGETFILE_1 :"
    cat difference
endif
/bin/rm -f difference

# find diffs
diff art.n.count $TARGETFILE_2 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_2)"
else
    echo "Following differences exist between art.n.count and $TARGETFILE_2 :"
    cat difference
endif
/bin/rm -f difference

# find diffs
diff authority.n.xml $TARGETFILE_3 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_3)"
else
    echo "Following differences exist between authority.n.xml and $TARGETFILE_3 :"
    cat difference
endif
/bin/rm -f difference

# find diffs
diff authority.n.count $TARGETFILE_4 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_4)"
else
    echo "Following differences exist between authority.n.count and $TARGETFILE_4 :"
    cat difference
endif
/bin/rm -f difference

/bin/rm -f art.n.xml
/bin/rm -f art.n.count
/bin/rm -f authority.n.xml
/bin/rm -f authority.n.count

# and now on the test.xml file

# subtest 2
echo "Running preprocess.pl on test.xml using token.txt"

set TESTFILE     = "test.xml"
set TOKENFILE    = "token.txt"

set TARGETFILE_1 = "art.test.xml.reqd"   
set TARGETFILE_2 = "art.test.count.reqd"   
set TARGETFILE_3 = "authority.test.xml.reqd"   
set TARGETFILE_4 = "authority.test.count.reqd"   

# first check if these files exist. if any one does not, quit
if (!(-e $TESTFILE)) then
    echo "File $TESTFILE does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_1)) then
    echo "File $TARGETFILE_1 does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_2)) then
    echo "File $TARGETFILE_2 does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_3)) then
    echo "File $TARGETFILE_3 does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_4)) then
    echo "File $TARGETFILE_4 does not exist... aborting"
    exit
endif

# test on test.xml...
echo "Testing preprocess thusly: preprocess.pl $TESTFILE"
preprocess.pl $TESTFILE --token $TOKENFILE

# find diffs
diff art.n.xml $TARGETFILE_1 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_1)"
else
    echo "Following differences exist between art.n.xml and $TARGETFILE_1 :"
    cat difference
endif
/bin/rm -f difference

# find diffs
diff art.n.count $TARGETFILE_2 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_2)"
else
    echo "Following differences exist between art.n.count and $TARGETFILE_2 :"
    cat difference
endif
/bin/rm -f difference

# find diffs
diff authority.n.xml $TARGETFILE_3 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_3)"
else
    echo "Following differences exist between authority.n.xml and $TARGETFILE_3 :"
    cat difference
endif
/bin/rm -f difference

# find diffs
diff authority.n.count $TARGETFILE_4 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_4)"
else
    echo "Following differences exist between authority.n.count and $TARGETFILE_4 :"
    cat difference
endif
/bin/rm -f difference

/bin/rm -f art.n.xml
/bin/rm -f art.n.count
/bin/rm -f authority.n.xml
/bin/rm -f authority.n.count

